import click


@click.command()
@click.argument('find_string')
@click.argument('replace_string')
@click.option('--file_pattern', '-f', default=".*",
              help='Define a file pattern')
@click.option('--dry-run', '-d', is_flag=True, default=False,
              help='print only replace')
def replace(find_string, file_pattern, replace_string, dry_run):
    """Find and replace a string in all repos"""
    from octohot.cli.config import repositories
    from octohot.cli.regex.file import File
    for repo in repositories:
        files = repo.files(file_pattern)
        for file in files:
            try:
                f = File(file)
                f.replace(find_string, replace_string, dry_run)
            except UnicodeDecodeError as e:
                pass



import click
import os


@click.command()
@click.argument('find_string')
@click.option('--file_pattern', '-f', default=".*",
              help='Define a file pattern')
@click.option('--only_filepath', '-p', is_flag=True,
              help='print only filepaths')
@click.option('--short-output', '-s', is_flag=True, default=False,
              help='summarize filename and output in same line')
def find(find_string, file_pattern, only_filepath, short_output):
    """
    Find a regular expression in all repos
    """
    from octohot.cli.config import repositories
    from octohot.cli.regex.file import File
    for repo in repositories:
        files = repo.files(file_pattern)
        for file in files:
            try:
                f = File(file)
                matches = f.find(find_string)
                if matches:
                    for match in matches:
                        if short_output:
                            if only_filepath:
                                click.echo(
                                    "%s (%s:%s)\t" % (
                                        file.replace(os.getcwd(), '.'),
                                        f.line(match.start()),
                                        f.line(match.end())
                                    )
                                )
                            else:
                                click.echo(
                                    "%s (%s:%s)\t%s" % (
                                        file.replace(os.getcwd(), '.'),
                                        f.line(match.start()),
                                        f.line(match.end()),
                                        match.group().decode('utf-8')
                                    )
                                )
                        else:
                            click.echo(
                                "%s (%s:%s)" % (
                                    file.replace(os.getcwd(), '.'),
                                    f.line(match.start()),
                                    f.line(match.end())
                                )
                            )
                            if not only_filepath:
                                click.echo(match.group())
            except UnicodeDecodeError as e:
                pass



import click
from octohot.cli.sync import sync
from octohot.cli.apply import apply
from .git import git
from .github import github
from .regex import regex


@click.group()
@click.option('--verbose', '-v', is_flag=True, help='Enables verbose mode.')
def cli(verbose=True):
    """Command line interface for the octohot package"""
    if verbose:
        import logging
        logging.getLogger().setLevel(logging.INFO)


@click.command()
def version():
    """Display the current version."""
    import pkg_resources  # part of setuptools
    version_str = pkg_resources.require("octohot")[0].version
    click.echo('version: %s' % version_str)


cli.add_command(version)
cli.add_command(sync)
cli.add_command(apply)
cli.add_command(git.git)
cli.add_command(github.github)
cli.add_command(regex.regex)

if __name__ == '__main__':
    cli()
